Window

Struct Window 

pub struct Window { /* private fields */ }

Implementations

Source

impl Window

pub fn new(width: u32, height: u32, title: &str) -> Result<Self, Errors>

Create a new window with the given width and height and title, and enable polling for the given window events. If the window cannot be created, returns an error of type Errors::WindowCreationError.

Arguments
  • width - The width of the window in pixels.
  • height - The height of the window in pixels.
  • title - The title of the window.
Returns

A Result containing a Window instance if successful, or an error of type Errors::WindowCreationError otherwise.

pub fn init_gl(&mut self) -> Result<(), Errors>

Initialize the OpenGL context for the window.

This function sets the current context to the window’s OpenGL context and loads the OpenGL function pointers using the gl crate.

Errors

This function will return an error if there are any OpenGL errors during the initialization process.

pub fn should_close(&self) -> bool

Check if the window should close.

Returns

true if the window should close, otherwise false.

pub fn enable_depth_test(&self)

Enable depth testing for this window.

OpenGL Functions

This function is a wrapper around glEnable(GL_DEPTH_TEST).

pub fn enable_blend(&self)

Enable blending for this window.

OpenGL Functions

This function is a wrapper around glEnable(GL_BLEND) and glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA).

pub fn clear(&self, r: f32, g: f32, b: f32, a: f32)

Clear the screen with the given color.

OpenGL Functions

This function is a wrapper around glClearColor and glClear.

Arguments
  • r - The red component of the color.
  • g - The green component of the color.
  • b - The blue component of the color.
  • a - The alpha component of the color.
pub fn update(&mut self)

Process window events and swap the front and back buffers.

This must be called every frame to keep the window responsive.