pub struct Window { /* private fields */ }Implementations
Sourceimpl Window
impl Window
Sourcepub fn new(width: u32, height: u32, title: &str) -> Result<Self, Errors>
pub fn new(width: u32, height: u32, title: &str) -> Result<Self, Errors>
Create a new window with the given width and height and title, and enable polling
for the given window events. If the window cannot be created, returns an error of
type Errors::WindowCreationError.
Arguments
width- The width of the window in pixels.height- The height of the window in pixels.title- The title of the window.
Returns
A Result containing a Window instance if successful, or an error of type
Errors::WindowCreationError otherwise.
Sourcepub fn init_gl(&mut self) -> Result<(), Errors>
pub fn init_gl(&mut self) -> Result<(), Errors>
Initialize the OpenGL context for the window.
This function sets the current context to the window’s OpenGL context
and loads the OpenGL function pointers using the gl crate.
Errors
This function will return an error if there are any OpenGL errors during the initialization process.
Sourcepub fn should_close(&self) -> bool
pub fn should_close(&self) -> bool
Sourcepub fn enable_depth_test(&self)
pub fn enable_depth_test(&self)
Enable depth testing for this window.
OpenGL Functions
This function is a wrapper around glEnable(GL_DEPTH_TEST).
Sourcepub fn enable_blend(&self)
pub fn enable_blend(&self)
Enable blending for this window.
OpenGL Functions
This function is a wrapper around glEnable(GL_BLEND) and
glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA).